#!/bin/bash
# Filename: build-tk.sh
# Automates the packaging process of the software "tk" for
# use with Zenwalk Linux.  
# Copyright (C) 2009 Michael Verret michael.verret@gmail.com
# Software source: http://www.tcl.tk/
# Software dependencies: ""

WorkArea=$(pwd)
SoftwareName='tk'
SoftwareVersion='8.5.7'
CompressionAlgorithm='tar.gz'
Arch='i686'
Build='62.1'
Package="$SoftwareName-$SoftwareVersion-$Arch-$Build"
InstallDir="$WorkArea/$Package"
DocDir="$InstallDir/usr/doc/$SoftwareName-$SoftwareVersion"
SrcDir="$InstallDir/usr/src/$SoftwareName-$SoftwareVersion"
Documentation="ChangeLog ChangeLog.2002 ChangeLog.2004 README changes \
	license.terms"

# Files from previous builds are considered cruft.
Cruft="$SoftwareName-$SoftwareVersion $Package $Package.*"
for Each in ${Cruft} ; do
	if [ -e $Each ] ; then
		rm -rf $Each
	fi
done

tar -xvzf $SoftwareName$SoftwareVersion-src.$CompressionAlgorithm

mv $SoftwareName$SoftwareVersion $SoftwareName-$SoftwareVersion
cd $SoftwareName-$SoftwareVersion/unix
chown -R root:root .
find . \
	\( -perm 777 -o -perm 775 -o -perm 711 -o -perm 555 -o -perm 511 \) \
	-exec chmod 755 {} \; -o \
	\( -perm 666 -o -perm 664 -o -perm 600 -o -perm 444 -o -perm 440 -o -perm 400 \) \
	-exec chmod 644 {} \;

./configure CFLAGS="-O2 -march=$Arch -pipe" CXXFLAGS="-O2 -march=$Arch -pipe" \
	--prefix=/usr --mandir=/usr/man --enable-shared --enable-man-symlinks \
	--enable-man-compression=gzip --enable-threads --enable-xft \
	--disable-64bit --silent

make || exit 1
make INSTALL_ROOT=$InstallDir install install-private-headers || exit 1

# Add useful symlinks:
cd $InstallDir/usr/bin ; rm -f wish ; ln -sf wish8.5 wish
cd $InstallDir/usr/lib ; rm -f libtk.so ; ln -sf libtk8.5.so libtk.so

cd $InstallDir
	find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : |  \
		xargs strip --strip-unneeded 2> /dev/null
	find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | \
		xargs strip --strip-unneeded 2> /dev/null

mkdir -p $InstallDir/install
cat <<EOF0 > $InstallDir/install/slack-desc 
  |-----handy-ruler------------------------------------------------------|
tk: tk (Open source, cross-platform widget toolkit)
tk:
tk: Tk is an open source, cross-platform widget toolkit,
tk: that is, a library of basic elements for building a
tk: graphical user interface (GUI). Tk provides a number
tk: of widgets commonly needed to develop desktop
tk: applications such as button, menu, canvas, text, frame,
tk: label etc.
tk:
tk:
tk:
EOF0

mkdir -p $DocDir
cd $WorkArea/$SoftwareName-$SoftwareVersion
	cp $Documentation $DocDir

mkdir -p $SrcDir
cd $WorkArea ; cp build-$SoftwareName.sh $SrcDir

cd $InstallDir ; makepkg -l y -c n $InstallDir.tlz
	
cd $WorkArea
	depfinder -f $Package.tlz
	md5sum $Package.tlz > $Package.md5
	rm -rf $SoftwareName-$SoftwareVersion $InstallDir

# CHANGELOG:
# ~ Sun Apr 19 2009	Michael Verret "axxium" michael.verret@gmail.com
# ~ Updated: tk-8.5.7

# ~ Thu Jan 22nd 2009 Michael Verret "axxium" <michael.verret@gmail.com>
# ~ Updated: tk-8.5.6

# ~ Thu Sep 11 2008 Michael Verret "axxium" <michael.verret@gmail.com>
# ~ Initial build: tk-8.5.4
